
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_e_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.151457'}

wordnet_terms_e = [
    'ea',
    'each',
    'eacles',
    'eadwig',
    'eager',
    'eagerly',
    'eagerness',
    'eagle',
    'eagled',
    'eagles',
    'eaglet',
    'eagre',
    'eames',
    'ear',
    'earache',
    'eardrop',
    'eardrum',
    'eared',
    'earflap',
    'earful',
    'earhart',
    'earl',
    'earlap',
    'earldom',
    'earless',
    'earlier',
    'earliest',
    'earliness',
    'earlobe',
    'early',
    'earlyish',
    'earmark',
    'earmarked',
    'earmarks',
    'earmuff',
    'earn',
    'earned',
    'earner',
    'earners',
    'earnest',
    'earnestly',
    'earnestness',
    'earning',
    'earnings',
    'earns',
    'earphone',
    'earphones',
    'earpiece',
    'earplug',
    'earreach',
    'earring',
    'earrings',
    'ears',
    'earshot',
    'earsplitting',
    'earth',
    'earthball',
    'earthballs',
    'earthborn',
    'earthbound',
    'earthen',
    'earthenware',
    'earthing',
    'earthlike',
    'earthling',
    'earthly',
    'earthman',
    'earthnut',
    'earthquake',
    'earthquakes',
    'earths',
    'earthshaking',
    'earthstar',
    'earthstars',
    'earthtongue',
    'earthtongues',
    'earthwork',
    'earthworm',
    'earthworms',
    'earthy',
    'earwax',
    'earwig',
    'earwigs',
    'earworms',
    'eas',
    'ease',
    'eased',
    'easel',
    'easement',
    'eases',
    'easier',
    'easiest',
    'easily',
    'easiness',
    'easing',
    'east',
    'eastbound',
    'easter',
    'easterly',
    'eastern',
    'easterner',
    'easternmost',
    'eastertide',
    'eastman',
    'eastmost',
    'eastside',
    'eastward',
    'easy',
    'easygoing',
    'easygoingness',
    'eat',
    'eatable',
    'eatables',
    'eatage',
    'eaten',
    'eater',
    'eaters',
    'eatery',
    'eating',
    'eats',
    'eaves',
    'eavesdrop',
    'eavesdropper',
    'eavesdropping',
    'eb',
    'ebb',
    'ebbed',
    'ebbing',
    'ebbtide',
    'ebenaceae',
    'ebenales',
    'eberhart',
    'ebionite',
    'ebionites',
    'ebit',
    'ebitda',
    'eblis',
    'ebn',
    'ebola',
    'ebon',
    'ebonics',
    'ebonise',
    'ebonite',
    'ebonize',
    'ebony',
    'ebracteate',
    'ebro',
    'ebs',
    'ebullience',
    'ebullient',
    'ebullition',
    'eburnation',
    'eburophyton',
    'ebv',
    'ec',
    'ecarte',
    'ecballium',
    'ecc',
    'eccentric',
    'eccentricity',
    'ecchymosis',
    'eccles',
    'ecclesiastes',
    'ecclesiastic',
    'ecclesiastical',
    'ecclesiasticism',
    'ecclesiasticus',
    'ecclesiology',
    'eccm',
    'eccrine',
    'eccyesis',
    'ecdemic',
    'ecdysiast',
    'ecdysis',
    'ecesis',
    'ecf',
    'ecg',
    'echelon',
    'echeneididae',
    'echeneis',
    'echidna',
    'echidnas',
    'echidnophaga',
    'echinacea',
    'echinocactus',
    'echinocereus',
    'echinochloa',
    'echinococci',
    'echinococcosis',
    'echinococcus',
    'echinoderm',
    'echinodermata',
    'echinoderms',
    'echinoidea',
    'echinops',
    'echinus',
    'echium',
    'echo',
    'echocardiogram',
    'echocardiograph',
    'echocardiography',
    'echoed',
    'echoencephalogram',
    'echoencephalograph',
    'echoencephalography',
    'echoes',
    'echogram',
    'echography',
    'echoic',
    'echoing',
    'echolalia',
    'echoless',
    'echolike',
    'echolocation',
    'echovirus',
    'echt',
    'eck',
    'eckhart',
    'eclair',
    'eclampsia',
    'eclat',
    'eclectic',
    'eclecticism',
    'eclecticist',
    'eclipse',
    'eclipsed',
    'eclipses',
    'eclipsing',
    'eclipsis',
    'ecliptic',
    'eclogue',
    'ecm',
    'ecobabble',
    'ecologic',
    'ecological',
    'ecologically',
    'ecologist',
    'ecology',
    'econometric',
    'econometrician',
    'econometrics',
    'econometrist',
    'economic',
    'economical',
    'economically',
    'economics',
    'economise',
    'economiser',
    'economist',
    'economists',
    'economize',
    'economizer',
    'economy',
    'ecosoc',
    'ecosystem',
    'ecosystems',
    'ecoterrorism',
    'ecotourism',
    'ecphonesis',
    'ecrevisse',
    'ecru',
    'ecstasy',
    'ecstatic',
    'ect',
    'ectasia',
    'ectasis',
    'ectoblast',
    'ectoderm',
    'ectodermal',
    'ectodermic',
    'ectomorph',
    'ectomorphic',
    'ectomorphy',
    'ectoparasite',
    'ectopia',
    'ectopic',
    'ectopistes',
    'ectoplasm',
    'ectoproct',
    'ectoprocta',
    'ectotherm',
    'ectothermic',
    'ectozoan',
    'ectozoon',
    'ectrodactyly',
    'ecuador',
    'ecuadoran',
    'ecuadorian',
    'ecumenic',
    'ecumenical',
    'ecumenicalism',
    'ecumenicism',
    'ecumenism',
    'eczema',
    'ed',
    'edacious',
    'edacity',
    'edam',
    'edaphosauridae',
    'edaphosaurus',
    'edd',
    'edda',
    'eddies',
    'eddington',
    'eddo',
    'eddy',
    'edecrin',
    'edelweiss',
    'edema',
    'edematous',
    'eden',
    'edental',
    'edentata',
    'edentate',
    'edentates',
    'edentulate',
    'edentulous',
    'ederle',
    'edgar',
    'edge',
    'edged',
    'edgeless',
    'edger',
    'edges',
    'edginess',
    'edging',
    'edgy',
    'edibility',
    'edible',
    'edibleness',
    'edict',
    'edification',
    'edifice',
    'edified',
    'edify',
    'edifying',
    'edinburgh',
    'edirne',
    'edison',
    'edit',
    'edited',
    'edith',
    'editing',
    'edition',
    'editions',
    'editor',
    'editorial',
    'editorialise',
    'editorialist',
    'editorialize',
    'editorials',
    'editors',
    'editorship',
    'edits',
    'edman',
    'edmond',
    'edmonton',
    'edmontonia',
    'edmontosaurus',
    'edmund',
    'edo',
    'edp',
    'edronax',
    'eds',
    'edta',
    'educate',
    'educated',
    'educatee',
    'educates',
    'educating',
    'education',
    'educational',
    'educationalist',
    'educationist',
    'educative',
    'educator',
    'educe',
    'edulcorate',
    'edulis',
    'edutainment',
    'edward',
    'edwardian',
    'edwards',
    'edwin',
    'edwy',
    'ee',
    'eec',
    'eeg',
    'eel',
    'eelam',
    'eelblenny',
    'eelgrass',
    'eellike',
    'eelpout',
    'eelpouts',
    'eels',
    'eelworm',
    'eelworms',
    'eerie',
    'eeriness',
    'eero',
    'eery',
    'efef',
    'eff',
    'efface',
    'effaceable',
    'effacement',
    'effect',
    'effected',
    'effecter',
    'effecting',
    'effective',
    'effectively',
    'effectiveness',
    'effectivity',
    'effector',
    'effects',
    'effectual',
    'effectuality',
    'effectualness',
    'effectuate',
    'effectuation',
    'effeminacy',
    'effeminate',
    'effeminateness',
    'effeminise',
    'effeminize',
    'effendi',
    'efferent',
    'efferentia',
    'effervesce',
    'effervescence',
    'effervescent',
    'effervescing',
    'effete',
    'efficacious',
    'efficaciousness',
    'efficacy',
    'efficiency',
    'efficient',
    'efficiently',
    'effigies',
    'effigy',
    'effleurage',
    'effloresce',
    'effloresced',
    'efflorescence',
    'efflorescent',
    'effluence',
    'effluent',
    'effluvium',
    'efflux',
    'effort',
    'effortful',
    'effortfulness',
    'effortless',
    'effortlessly',
    'effortlessness',
    'efforts',
    'effrontery',
    'effulgence',
    'effulgent',
    'effuse',
    'effuses',
    'effusion',
    'effusive',
    'effusively',
    'effusiveness',
    'eft',
    'eg',
    'egadi',
    'egalitarian',
    'egalitarianism',
    'egalite',
    'egality',
    'egbert',
    'egeria',
    'egest',
    'egg',
    'eggar',
    'eggars',
    'eggbeater',
    'eggcup',
    'egged',
    'egger',
    'eggfruit',
    'egghead',
    'eggleston',
    'eggnog',
    'eggplant',
    'eggs',
    'eggshake',
    'eggshell',
    'eggwhisk',
    'egis',
    'eglantine',
    'eglevsky',
    'ego',
    'egocentric',
    'egocentrism',
    'egoism',
    'egoist',
    'egoistic',
    'egoistical',
    'egomania',
    'egomaniac',
    'egotism',
    'egotist',
    'egotistic',
    'egotistical',
    'egotrip',
    'egotrips',
    'egregious',
    'egress',
    'egression',
    'egret',
    'egrets',
    'egretta',
    'egtk',
    'egypt',
    'egyptian',
    'egyptians',
    'egyptologist',
    'egyptology',
    'ehadhamen',
    'ehf',
    'ehrenberg',
    'ehrlich',
    'eib',
    'eibit',
    'eichhornia',
    'eichmann',
    'eider',
    'eiderdown',
    'eidetic',
    'eidos',
    'eiffel',
    'eigen',
    'eigenvalue',
    'eight',
    'eighteen',
    'eighteenth',
    'eighter',
    'eightfold',
    'eighth',
    'eighties',
    'eightieth',
    'eightpence',
    'eightpenny',
    'eightsome',
    'eightvo',
    'eighty',
    'eijkman',
    'eimeria',
    'eimeriidae',
    'eindhoven',
    'einstein',
    'einsteinian',
    'einsteinium',
    'einthoven',
    'eira',
    'eire',
    'eisegesis',
    'eisenhower',
    'eisenstaedt',
    'eisenstein',
    'eisteddfod',
    'either',
    'ejaculate',
    'ejaculated',
    'ejaculates',
    'ejaculation',
    'ejaculator',
    'ejaculatory',
    'eject',
    'ejected',
    'ejecting',
    'ejection',
    'ejector',
    'ejects',
    'eked',
    'ekg',
    'ekman',
    'el',
    'ela',
    'elaborate',
    'elaborated',
    'elaborately',
    'elaborateness',
    'elaborates',
    'elaboration',
    'elaeagnaceae',
    'elaeagnus',
    'elaeis',
    'elaeocarpaceae',
    'elaeocarpus',
    'elagatis',
    'elam',
    'elamite',
    'elamites',
    'elamitic',
    'elan',
    'eland',
    'elands',
    'elanoides',
    'elanus',
    'elaphe',
    'elaphure',
    'elaphurus',
    'elapid',
    'elapidae',
    'elapse',
    'elapsed',
    'elapses',
    'elasmobranch',
    'elasmobranchii',
    'elastance',
    'elastase',
    'elastic',
    'elasticised',
    'elasticity',
    'elasticized',
    'elastin',
    'elastomer',
    'elastoplast',
    'elastosis',
    'elate',
    'elated',
    'elater',
    'elaterid',
    'elateridae',
    'elating',
    'elation',
    'elavil',
    'elbe',
    'elbow',
    'elbowing',
    'elbows',
    'eld',
    'elder',
    'elderberries',
    'elderberry',
    'elderly',
    'elders',
    'eldership',
    'eldest',
    'eldorado',
    'eldritch',
    'eleanor',
    'elecampane',
    'elect',
    'elected',
    'electing',
    'election',
    'electioneer',
    'electioneering',
    'elections',
    'elective',
    'elector',
    'electoral',
    'electorate',
    'electors',
    'electra',
    'electric',
    'electrical',
    'electrically',
    'electrician',
    'electricians',
    'electricity',
    'electrification',
    'electrified',
    'electrify',
    'electrifying',
    'electrocardiogram',
    'electrocardiograph',
    'electrocardiographic',
    'electrocardiography',
    'electrocautery',
    'electrochemical',
    'electrochemistry',
    'electrocute',
    'electrocution',
    'electrocutioner',
    'electrode',
    'electrodeposition',
    'electrodes',
    'electrodynamometer',
    'electroencephalogram',
    'electroencephalograph',
    'electroencephalographic',
    'electrograph',
    'electrologist',
    'electrolysis',
    'electrolyte',
    'electrolytes',
    'electrolytic',
    'electromagnet',
    'electromagnetic',
    'electromagnetics',
    'electromagnetism',
    'electromechanical',
    'electrometer',
    'electromotive',
    'electromyogram',
    'electromyograph',
    'electromyography',
    'electron',
    'electronegative',
    'electronegativity',
    'electroneutral',
    'electronic',
    'electronically',
    'electronics',
    'electrons',
    'electrophoresis',
    'electrophoretic',
    'electrophoridae',
    'electrophorus',
    'electroplate',
    'electroplater',
    'electroplating',
    'electropositive',
    'electroretinogram',
    'electroscope',
    'electroshock',
    'electrosleep',
    'electrostatic',
    'electrostatically',
    'electrostatics',
    'electrosurgery',
    'electrotherapist',
    'electrotherapy',
    'electrum',
    'elects',
    'eleemosynary',
    'elegance',
    'elegans',
    'elegant',
    'elegantly',
    'elegiac',
    'elegise',
    'elegist',
    'elegize',
    'elegy',
    'element',
    'elemental',
    'elementary',
    'elements',
    'elemi',
    'eleocharis',
    'eleotridae',
    'elephant',
    'elephantiasis',
    'elephantidae',
    'elephantine',
    'elephantopus',
    'elephants',
    'elephas',
    'elettaria',
    'eleusine',
    'eleutherodactylus',
    'elevate',
    'elevated',
    'elevating',
    'elevation',
    'elevations',
    'elevator',
    'elevators',
    'eleven',
    'eleventh',
    'elf',
    'elfin',
    'elfish',
    'elflike',
    'elgar',
    'elia',
    'elias',
    'elicit',
    'elicitation',
    'elicited',
    'eliciting',
    'elicits',
    'elide',
    'elided',
    'eligibility',
    'eligible',
    'elijah',
    'eliminate',
    'eliminated',
    'eliminates',
    'eliminating',
    'elimination',
    'eliminator',
    'elint',
    'elinvar',
    'eliomys',
    'eliot',
    'elisa',
    'elisabethville',
    'elision',
    'elite',
    'elitism',
    'elitist',
    'elixir',
    'elixophyllin',
    'elizabeth',
    'elizabethan',
    'elk',
    'elkhound',
    'elkwood',
    'ell',
    'ellas',
    'ellen',
    'elli',
    'ellice',
    'ellington',
    'ellipse',
    'ellipses',
    'ellipsis',
    'ellipsoid',
    'ellipsoidal',
    'elliptic',
    'elliptica',
    'elliptical',
    'ellipticity',
    'ellis',
    'ellison',
    'ellsworth',
    'ellul',
    'elm',
    'elmont',
    'elms',
    'elmwood',
    'eln',
    'elocute',
    'elocuted',
    'elocution',
    'elocutionary',
    'elocutionist',
    'elodea',
    'elongate',
    'elongated',
    'elongation',
    'elope',
    'eloped',
    'elopement',
    'elopidae',
    'elops',
    'eloquence',
    'eloquent',
    'elsass',
    'else',
    'elsewhere',
    'elsholtzia',
    'elspar',
    'elton',
    'eluate',
    'elucidate',
    'elucidating',
    'elucidation',
    'elucidative',
    'elude',
    'eluded',
    'eludes',
    'eluding',
    'elul',
    'elusion',
    'elusive',
    'elusiveness',
    'elute',
    'elution',
    'elver',
    'elves',
    'elvis',
    'elvish',
    'elymus',
    'elysian',
    'elysium',
    'elytron',
    'em',
    'emaciate',
    'emaciated',
    'emaciation',
    'email',
    'emanate',
    'emanates',
    'emanating',
    'emanation',
    'emancipate',
    'emancipated',
    'emancipating',
    'emancipation',
    'emancipationist',
    'emancipative',
    'emancipator',
    'emarginate',
    'emasculate',
    'emasculated',
    'emasculation',
    'embalm',
    'embalmed',
    'embalmer',
    'embalming',
    'embalmment',
    'embank',
    'embanked',
    'embankment',
    'embargo',
    'embargoes',
    'embark',
    'embarkation',
    'embarked',
    'embarkment',
    'embarrass',
    'embarrassed',
    'embarrasses',
    'embarrassing',
    'embarrassingly',
    'embarrassment',
    'embassador',
    'embassies',
    'embassy',
    'embattle',
    'embattled',
    'embayment',
    'embed',
    'embedded',
    'embedding',
    'embellish',
    'embellished',
    'embellishing',
    'embellishment',
    'embellishments',
    'ember',
    'emberiza',
    'emberizidae',
    'embers',
    'embezzle',
    'embezzled',
    'embezzlement',
    'embezzler',
    'embezzling',
    'embiodea',
    'embioptera',
    'embiotocidae',
    'embitter',
    'embittered',
    'embitterment',
    'emblazon',
    'emblazoned',
    'emblem',
    'emblematic',
    'emblematical',
    'embodied',
    'embodies',
    'embodiment',
    'embody',
    'embodying',
    'embolden',
    'emboldened',
    'embolectomy',
    'embolic',
    'embolism',
    'embolus',
    'embonpoint',
    'emboss',
    'embossed',
    'embossment',
    'embothrium',
    'embouchure',
    'embower',
    'embrace',
    'embraced',
    'embracement',
    'embracing',
    'embrance',
    'embrangle',
    'embrasure',
    'embrasures',
    'embrittle',
    'embrocate',
    'embrocation',
    'embroider',
    'embroidered',
    'embroiderer',
    'embroideress',
    'embroidering',
    'embroidery',
    'embroil',
    'embroiled',
    'embroilment',
    'embrown',
    'embryo',
    'embryologic',
    'embryologist',
    'embryology',
    'embryonal',
    'embryonic',
    'embryos',
    'embryotic',
    'emcee',
    'emda',
    'emeer',
    'emend',
    'emendation',
    'emended',
    'emerald',
    'emeralds',
    'emerge',
    'emerged',
    'emergence',
    'emergencies',
    'emergency',
    'emergent',
    'emerges',
    'emerging',
    'emeritus',
    'emersion',
    'emerson',
    'emery',
    'emeside',
    'emesis',
    'emetic',
    'emetics',
    'emetrol',
    'emf',
    'emg',
    'emigrant',
    'emigrate',
    'emigrated',
    'emigration',
    'emigre',
    'emigree',
    'emile',
    'emilia',
    'emiliano',
    'emilion',
    'emily',
    'eminence',
    'eminences',
    'eminent',
    'eminently',
    'emir',
    'emirate',
    'emirates',
    'emissary',
    'emission',
    'emissions',
    'emit',
    'emits',
    'emitted',
    'emitter',
    'emitting',
    'emma',
    'emmanthe',
    'emmenagogue',
    'emmental',
    'emmentaler',
    'emmenthal',
    'emmenthaler',
    'emmer',
    'emmet',
    'emmetropia',
    'emmetropic',
    'emmy',
    'emollient',
    'emolument',
    'emoluments',
    'emote',
    'emoticon',
    'emotion',
    'emotional',
    'emotionalism',
    'emotionality',
    'emotionally',
    'emotionless',
    'emotionlessness',
    'emotions',
    'emotive',
    'empale',
    'empanel',
    'empathetic',
    'empathic',
    'empathise',
    'empathize',
    'empathy',
    'empedocles',
    'empennage',
    'emperor',
    'emperors',
    'empetraceae',
    'empetrum',
    'emphasis',
    'emphasise',
    'emphasised',
    'emphasize',
    'emphasized',
    'emphasizes',
    'emphasizing',
    'emphatic',
    'emphatically',
    'emphysema',
    'emphysematous',
    'empire',
    'empiric',
    'empirical',
    'empirically',
    'empiricism',
    'empiricist',
    'empirin',
    'empiristic',
    'emplace',
    'emplaced',
    'emplacement',
    'emplane',
    'employ',
    'employable',
    'employed',
    'employee',
    'employees',
    'employer',
    'employers',
    'employing',
    'employment',
    'employs',
    'emporium',
    'empower',
    'empowered',
    'empowering',
    'empowerment',
    'empress',
    'emptied',
    'empties',
    'emptiness',
    'emptor',
    'empty',
    'emptying',
    'empurple',
    'empurpled',
    'empyema',
    'empyreal',
    'empyrean',
    'emu',
    'emulate',
    'emulating',
    'emulation',
    'emulator',
    'emulous',
    'emulsified',
    'emulsifier',
    'emulsifiers',
    'emulsify',
    'emulsifying',
    'emulsion',
    'emulsions',
    'emus',
    'emydidae',
    'en',
    'enable',
    'enabled',
    'enables',
    'enabling',
    'enact',
    'enacted',
    'enacting',
    'enactment',
    'enacts',
    'enalapril',
    'enallage',
    'enamel',
    'enameled',
    'enamels',
    'enamelware',
    'enamine',
    'enamor',
    'enamored',
    'enamoredness',
    'enamour',
    'enamoured',
    'enanthem',
    'enanthema',
    'enantiomer',
    'enantiomorph',
    'enantiomorphism',
    'enarthrosis',
    'enate',
    'enatic',
    'enation',
    'enbrel',
    'encainide',
    'encamp',
    'encamping',
    'encampment',
    'encapsulate',
    'encapsulated',
    'encapsulation',
    'encase',
    'encased',
    'encasement',
    'encases',
    'encasing',
    'encaustic',
    'enceinte',
    'encelia',
    'enceliopsis',
    'encephalartos',
    'encephalitis',
    'encephalocele',
    'encephalogram',
    'encephalography',
    'encephalomeningitis',
    'encephalomyelitis',
    'encephalon',
    'encephalopathy',
    'enchain',
    'enchained',
    'enchant',
    'enchanted',
    'enchanter',
    'enchanting',
    'enchantment',
    'enchantress',
    'enchilada',
    'enchiridion',
    'enchondroma',
    'encipher',
    'encircle',
    'encircled',
    'encirclement',
    'encircles',
    'encircling',
    'enclave',
    'enclose',
    'enclosed',
    'encloses',
    'enclosing',
    'enclosure',
    'enclothe',
    'encode',
    'encoded',
    'encodes',
    'encoding',
    'encolure',
    'encomiastic',
    'encomium',
    'encompass',
    'encompasses',
    'encompassing',
    'encompassment',
    'encopresis',
    'encore',
    'encounter',
    'encountered',
    'encounters',
    'encourage',
    'encouraged',
    'encouragement',
    'encourages',
    'encouraging',
    'encrimson',
    'encroach',
    'encroacher',
    'encroaching',
    'encroachment',
    'encrust',
    'encrustation',
    'encrusted',
    'encrypt',
    'encrypted',
    'encryption',
    'enculturation',
    'encumber',
    'encumbered',
    'encumbering',
    'encumbrance',
    'encyclia',
    'encyclical',
    'encyclopaedia',
    'encyclopaedic',
    'encyclopaedism',
    'encyclopaedist',
    'encyclopedia',
    'encyclopedias',
    'encyclopedic',
    'encyclopedism',
    'encyclopedist',
    'encysted',
    'end',
    'endaemonism',
    'endameba',
    'endamoeba',
    'endamoebidae',
    'endanger',
    'endangered',
    'endangering',
    'endangerment',
    'endangers',
    'endarterectomy',
    'endarteritis',
    'endear',
    'endeared',
    'endearing',
    'endearment',
    'endeavor',
    'endeavour',
    'endecott',
    'ended',
    'endemic',
    'endemical',
    'endemism',
    'enderby',
    'endergonic',
    'endermatic',
    'endermic',
    'endgame',
    'endicott',
    'ending',
    'endings',
    'endive',
    'endless',
    'endlessness',
    'endmost',
    'endoblast',
    'endocarditis',
    'endocardium',
    'endocarp',
    'endocentric',
    'endocervicitis',
    'endocranium',
    'endocrinal',
    'endocrine',
    'endocrinologist',
    'endocrinology',
    'endoderm',
    'endodontia',
    'endodontic',
    'endodontics',
    'endodontist',
    'endoergic',
    'endogamic',
    'endogamous',
    'endogamy',
    'endogen',
    'endogenetic',
    'endogenic',
    'endogenous',
    'endogenously',
    'endogeny',
    'endolymph',
    'endometrial',
    'endometriosis',
    'endometritis',
    'endometrium',
    'endomorph',
    'endomorphic',
    'endomorphy',
    'endomycetales',
    'endoneurium',
    'endonuclease',
    'endoparasite',
    'endoparasitic',
    'endoplasm',
    'endoprocta',
    'endorphin',
    'endorse',
    'endorsed',
    'endorsement',
    'endorser',
    'endorses',
    'endorsing',
    'endoscope',
    'endoscopic',
    'endoscopy',
    'endoskeleton',
    'endosperm',
    'endospore',
    'endospores',
    'endosteum',
    'endothelial',
    'endothelium',
    'endothermal',
    'endothermic',
    'endotoxin',
    'endovenous',
    'endow',
    'endowed',
    'endowing',
    'endowment',
    'endozoan',
    'endozoic',
    'endplate',
    'endpoint',
    'endpoints',
    'ends',
    'endue',
    'endurable',
    'endurance',
    'endure',
    'endured',
    'enduring',
    'enduringness',
    'ene',
    'enema',
    'enemas',
    'enemies',
    'enemy',
    'energetic',
    'energetically',
    'energid',
    'energies',
    'energise',
    'energiser',
    'energising',
    'energize',
    'energized',
    'energizer',
    'energizing',
    'energy',
    'enervate',
    'enervated',
    'enervating',
    'enervation',
    'enesco',
    'enets',
    'enfeeble',
    'enfeeblement',
    'enfeebling',
    'enfeoff',
    'enfeoffed',
    'enfeoffment',
    'enfilade',
    'enflurane',
    'enfold',
    'enfolding',
    'enforce',
    'enforceable',
    'enforced',
    'enforcement',
    'enforcer',
    'enforces',
    'enforcing',
    'enfranchise',
    'enfranchised',
    'enfranchisement',
    'engage',
    'engaged',
    'engagement',
    'engages',
    'engaging',
    'engagingly',
    'engelmannia',
    'engels',
    'engender',
    'engild',
    'engine',
    'engineer',
    'engineered',
    'engineering',
    'engineers',
    'enginery',
    'engines',
    'england',
    'englanders',
    'english',
    'englishman',
    'englishmen',
    'englishwoman',
    'englut',
    'engorge',
    'engorged',
    'engorgement',
    'engraft',
    'engram',
    'engraulidae',
    'engraulis',
    'engrave',
    'engraved',
    'engraver',
    'engraves',
    'engraving',
    'engravings',
    'engross',
    'engrossed',
    'engrossing',
    'engrossment',
    'engulf',
    'engulfed',
    'engulfs',
    'enhance',
    'enhanced',
    'enhancement',
    'enhancer',
    'enhances',
    'enhancing',
    'enhancive',
    'enhydra',
    'enid',
    'enigma',
    'enigmatic',
    'enigmatical',
    'eniwetok',
    'enjambement',
    'enjambment',
    'enjoin',
    'enjoining',
    'enjoinment',
    'enjoy',
    'enjoyable',
    'enjoyableness',
    'enjoyed',
    'enjoyer',
    'enjoying',
    'enjoyment',
    'enjoys',
    'enkaid',
    'enkephalin',
    'enki',
    'enkidu',
    'enkindle',
    'enkindled',
    'enl',
    'enlace',
    'enlarge',
    'enlarged',
    'enlargement',
    'enlargements',
    'enlarger',
    'enlarges',
    'enlarging',
    'enlighten',
    'enlightened',
    'enlightening',
    'enlightenment',
    'enlil',
    'enlist',
    'enlisted',
    'enlistee',
    'enlisting',
    'enlistment',
    'enlists',
    'enliven',
    'enlivened',
    'enlivener',
    'enlivening',
    'enmesh',
    'enmeshed',
    'enmity',
    'ennead',
    'ennoble',
    'ennoblement',
    'ennobling',
    'ennui',
    'enol',
    'enolic',
    'enologist',
    'enology',
    'enophile',
    'enormity',
    'enormous',
    'enormously',
    'enormousness',
    'enosis',
    'enough',
    'enounce',
    'enovid',
    'enplane',
    'enquire',
    'enquirer',
    'enquiry',
    'enrage',
    'enraged',
    'enragement',
    'enrapture',
    'enraptured',
    'enrich',
    'enriched',
    'enrichment',
    'enrobe',
    'enrol',
    'enroll',
    'enrolled',
    'enrollee',
    'enrolling',
    'enrollment',
    'enrolls',
    'enrolment',
    'ensconce',
    'ensconced',
    'ensemble',
    'ensete',
    'enshrine',
    'enshrined',
    'enshroud',
    'ensiform',
    'ensign',
    'ensilage',
    'ensile',
    'ensis',
    'ensky',
    'enslave',
    'enslaved',
    'enslavement',
    'enslaves',
    'ensnare',
    'ensnares',
    'ensnarl',
    'ensorcelled',
    'ensuant',
    'ensue',
    'ensuing',
    'ensure',
    'ensures',
    'ensuring',
    'entablature',
    'entail',
    'entailed',
    'entailing',
    'entailment',
    'entails',
    'entandrophragma',
    'entangle',
    'entangled',
    'entanglement',
    'entanglements',
    'entangles',
    'entangling',
    'entasis',
    'entebbe',
    'entelea',
    'entelechy',
    'entellus',
    'entente',
    'enter',
    'enteral',
    'entered',
    'enteric',
    'enterics',
    'entering',
    'enteritidis',
    'enteritis',
    'enterobacteria',
    'enterobacteriaceae',
    'enterobiasis',
    'enterobius',
    'enteroceptor',
    'enterokinase',
    'enterolith',
    'enterolithiasis',
    'enterolobium',
    'enteron',
    'enteropathy',
    'enteroptosis',
    'enterostenosis',
    'enterostomy',
    'enterotomy',
    'enterotoxemia',
    'enterotoxin',
    'enterovirus',
    'enterprise',
    'enterpriser',
    'enterprises',
    'enterprising',
    'enterprisingness',
    'enters',
    'entertain',
    'entertained',
    'entertainer',
    'entertainers',
    'entertaining',
    'entertainment',
    'entertainments',
    'entertains',
    'enthalpy',
    'enthral',
    'enthrall',
    'enthralled',
    'enthralling',
    'enthrallment',
    'enthrone',
    'enthroned',
    'enthronement',
    'enthronisation',
    'enthronization',
    'enthuse',
    'enthusiasm',
    'enthusiasms',
    'enthusiast',
    'enthusiastic',
    'enthusiastically',
    'enthusiasts',
    'entice',
    'enticement',
    'enticements',
    'entices',
    'enticing',
    'entire',
    'entirely',
    'entireness',
    'entirety',
    'entities',
    'entitle',
    'entitled',
    'entitlement',
    'entitles',
    'entitling',
    'entity',
    'entlebucher',
    'entoblast',
    'entoderm',
    'entoloma',
    'entolomataceae',
    'entomb',
    'entombed',
    'entombment',
    'entomion',
    'entomologic',
    'entomological',
    'entomologist',
    'entomology',
    'entomophilous',
    'entomophobia',
    'entomophthora',
    'entomophthoraceae',
    'entomophthorales',
    'entomostraca',
    'entoparasite',
    'entoproct',
    'entoprocta',
    'entourage',
    'entozoa',
    'entozoan',
    'entozoic',
    'entozoon',
    'entrails',
    'entrain',
    'entrance',
    'entranced',
    'entrancement',
    'entrances',
    'entranceway',
    'entrancing',
    'entrant',
    'entrants',
    'entrap',
    'entrapment',
    'entrapped',
    'entreat',
    'entreaty',
    'entrecote',
    'entree',
    'entremets',
    'entrench',
    'entrenched',
    'entrenches',
    'entrenchment',
    'entrepot',
    'entrepreneur',
    'entrepreneurial',
    'entresol',
    'entric',
    'entries',
    'entropy',
    'entrust',
    'entrusted',
    'entry',
    'entryway',
    'entsi',
    'entsy',
    'entwine',
    'enucleate',
    'enucleation',
    'enuki',
    'enumerable',
    'enumerate',
    'enumerated',
    'enumerates',
    'enumeration',
    'enumerator',
    'enunciate',
    'enunciated',
    'enunciation',
    'enured',
    'enuresis',
    'envelop',
    'envelope',
    'enveloped',
    'envelopes',
    'enveloping',
    'envelopment',
    'envelops',
    'envenom',
    'enviable',
    'envied',
    'envious',
    'enviously',
    'enviousness',
    'environ',
    'environment',
    'environmental',
    'environmentalism',
    'environmentalist',
    'environmentalists',
    'environments',
    'environs',
    'envisage',
    'envisaged',
    'envision',
    'envisioned',
    'envisioning',
    'envoi',
    'envoy',
    'envy',
    'enwrap',
    'enwrapped',
    'enzootic',
    'enzymatic',
    'enzyme',
    'enzymes',
    'enzymologist',
    'enzymology',
    'eocene',
    'eohippus',
    'eolian',
    'eolic',
    'eolith',
    'eolithic',
    'eolotropic',
    'eon',
    'eonian',
    'eons',
    'eoraptor',
    'eos',
    'eosin',
    'eosinopenia',
    'eosinophil',
    'eosinophile',
    'eosinophilia',
    'eosinophilic',
    'eosinophils',
    'epa',
    'epacridaceae',
    'epacris',
    'epanalepsis',
    'epanaphora',
    'epanodos',
    'epanorthosis',
    'eparch',
    'eparchial',
    'eparchy',
    'epaulet',
    'epaulets',
    'epaulette',
    'epauliere',
    'epee',
    'epees',
    'ependyma',
    'epenthesis',
    'epenthetic',
    'epergne',
    'epha',
    'ephah',
    'ephahs',
    'ephedra',
    'ephedraceae',
    'ephedrine',
    'ephemera',
    'ephemeral',
    'ephemerality',
    'ephemeralness',
    'ephemerid',
    'ephemerida',
    'ephemeridae',
    'ephemeris',
    'ephemeron',
    'ephemeroptera',
    'ephemeropteran',
    'ephesian',
    'ephesians',
    'ephestia',
    'ephesus',
    'ephippidae',
    'ephippiorhynchus',
    'epi',
    'epic',
    'epical',
    'epicalyx',
    'epicanthic',
    'epicanthus',
    'epicardia',
    'epicardium',
    'epicarp',
    'epicarpal',
    'epicene',
    'epicenter',
    'epicentre',
    'epicondyle',
    'epicondylitis',
    'epicranium',
    'epics',
    'epictetus',
    'epicure',
    'epicurean',
    'epicureanism',
    'epicurism',
    'epicurus',
    'epicycle',
    'epicyclic',
    'epicyclical',
    'epicycloid',
    'epideictic',
    'epideictical',
    'epidemic',
    'epidemiologic',
    'epidemiological',
    'epidemiologist',
    'epidemiology',
    'epidendron',
    'epidendrum',
    'epidermal',
    'epidermic',
    'epidermis',
    'epidiascope',
    'epididymis',
    'epididymitis',
    'epidural',
    'epigaea',
    'epigastric',
    'epigastrium',
    'epigenesis',
    'epiglottis',
    'epiglottitis',
    'epigon',
    'epigone',
    'epigram',
    'epigrammatic',
    'epigrams',
    'epigraph',
    'epigraphy',
    'epikeratophakia',
    'epilachna',
    'epilate',
    'epilation',
    'epilator',
    'epilepsy',
    'epileptic',
    'epilithic',
    'epilobium',
    'epilog',
    'epilogue',
    'epimedium',
    'epimetheus',
    'epimorphic',
    'epinephelus',
    'epinephrin',
    'epinephrine',
    'epipactis',
    'epipaleolithic',
    'epiphany',
    'epiphenomenon',
    'epiphora',
    'epiphyllum',
    'epiphyseal',
    'epiphysial',
    'epiphysis',
    'epiphyte',
    'epiphytes',
    'epiphytic',
    'epiphytotic',
    'epiplexis',
    'epipremnum',
    'epirus',
    'episcia',
    'episcleritis',
    'episcopacy',
    'episcopal',
    'episcopalian',
    'episcopalianism',
    'episcopalians',
    'episcopate',
    'episiotomy',
    'episode',
    'episodes',
    'episodic',
    'episome',
    'epispadias',
    'episperm',
    'epistasis',
    'epistaxis',
    'episteme',
    'epistemic',
    'epistemological',
    'epistemologist',
    'epistemology',
    'epistle',
    'epistles',
    'epistolary',
    'epistolatory',
    'epistrophe',
    'epitaph',
    'epitaxy',
    'epithalamium',
    'epithelial',
    'epitheliod',
    'epithelioma',
    'epithelium',
    'epithet',
    'epitome',
    'epitomise',
    'epitomize',
    'epitope',
    'epizoa',
    'epizoan',
    'epizoic',
    'epizoon',
    'epizootic',
    'epoch',
    'epochal',
    'epochs',
    'epona',
    'eponym',
    'eponymic',
    'eponymous',
    'eponymy',
    'epos',
    'epoxy',
    'eprom',
    'epsilon',
    'epsom',
    'epstein',
    'eptatretus',
    'eptesicus',
    'eq',
    'equable',
    'equal',
    'equaled',
    'equalisation',
    'equalise',
    'equaliser',
    'equalitarian',
    'equalitarianism',
    'equality',
    'equalization',
    'equalize',
    'equalizer',
    'equalizes',
    'equally',
    'equals',
    'equanil',
    'equanimity',
    'equanimous',
    'equatability',
    'equate',
    'equated',
    'equating',
    'equation',
    'equations',
    'equator',
    'equatorial',
    'equerry',
    'equestrian',
    'equetus',
    'equiangular',
    'equid',
    'equidae',
    'equidistant',
    'equidistribution',
    'equilateral',
    'equilibrate',
    'equilibration',
    'equilibrise',
    'equilibrium',
    'equilibrize',
    'equine',
    'equines',
    'equinoctial',
    'equinox',
    'equinoxes',
    'equip',
    'equipage',
    'equiping',
    'equipment',
    'equipoise',
    'equipoised',
    'equipotent',
    'equipped',
    'equipping',
    'equiprobable',
    'equips',
    'equipt',
    'equisetaceae',
    'equisetales',
    'equisetatae',
    'equisetum',
    'equitable',
    'equitably',
    'equitation',
    'equity',
    'equivalence',
    'equivalent',
    'equivalents',
    'equivocal',
    'equivocalness',
    'equivocate',
    'equivocation',
    'equivocator',
    'equus',
    'eqyptian',
    'er',
    'era',
    'eradicable',
    'eradicate',
    'eradicated',
    'eradicating',
    'eradication',
    'eradicator',
    'eragrostis',
    'eranthis',
    'eras',
    'erasable',
    'erase',
    'erased',
    'eraser',
    'erasing',
    'erasmian',
    'erasmus',
    'erastianism',
    'erasure',
    'erasures',
    'erato',
    'eratosthenes',
    'erbium',
    'ercilla',
    'erebus',
    'erect',
    'erected',
    'erectile',
    'erecting',
    'erection',
    'erectness',
    'erects',
    'erectus',
    'eremite',
    'eremites',
    'eremitic',
    'eremitical',
    'eremitism',
    'ereshkigal',
    'ereshkigel',
    'erethism',
    'erethizon',
    'erethizontidae',
    'eretmochelys',
    'erewhon',
    'erg',
    'ergocalciferol',
    'ergodic',
    'ergodicity',
    'ergometer',
    'ergonomic',
    'ergonomics',
    'ergonovine',
    'ergosterol',
    'ergot',
    'ergotamine',
    'ergotic',
    'ergotism',
    'ergotrate',
    'ergotropic',
    'ergotropism',
    'ergs',
    'erianthus',
    'eric',
    'erica',
    'ericaceae',
    'ericales',
    'eridanus',
    'erie',
    'erigeron',
    'erignathus',
    'erik',
    'erin',
    'erinaceidae',
    'erinaceus',
    'eringo',
    'erinyes',
    'eriobotrya',
    'eriocaulaceae',
    'eriocaulon',
    'eriodictyon',
    'eriogonum',
    'eriophorum',
    'eriophyllum',
    'eriosoma',
    'eris',
    'eristic',
    'eristical',
    'erithacus',
    'eritrea',
    'eritrean',
    'erivan',
    'erlang',
    'erle',
    'erlenmeyer',
    'ermine',
    'ern',
    'erne',
    'ernest',
    'ernie',
    'ernst',
    'erode',
    'eroded',
    'eroding',
    'erodium',
    'erogenous',
    'erolia',
    'eros',
    'erose',
    'erosion',
    'erosions',
    'erosive',
    'erotic',
    'erotica',
    'erotically',
    'eroticism',
    'eroticize',
    'erotism',
    'err',
    'errancy',
    'errand',
    'errands',
    'errant',
    'erratic',
    'erratically',
    'erratum',
    'errhine',
    'erring',
    'erroneous',
    'erroneously',
    'erroneousness',
    'error',
    'errorless',
    'errors',
    'ersatz',
    'erse',
    'ert',
    'eruca',
    'eruct',
    'eructation',
    'erudite',
    'eruditely',
    'eruditeness',
    'erudition',
    'erupt',
    'erupted',
    'erupting',
    'eruption',
    'eruptions',
    'eruptive',
    'erupts',
    'erving',
    'erwinia',
    'eryngium',
    'eryngo',
    'erysimum',
    'erysipelas',
    'erysiphaceae',
    'erysiphales',
    'erysiphe',
    'erythema',
    'erythematosus',
    'erythematous',
    'erythrina',
    'erythrite',
    'erythroblast',
    'erythroblastosis',
    'erythroblasts',
    'erythrocebus',
    'erythrocin',
    'erythrocyte',
    'erythrocytes',
    'erythrocytolysin',
    'erythroderma',
    'erythroid',
    'erythrolysin',
    'erythromycin',
    'erythronium',
    'erythropoiesis',
    'erythropoietic',
    'erythropoietin',
    'erythroxylaceae',
    'erythroxylon',
    'erythroxylum',
    'es',
    'esaki',
    'esau',
    'escadrille',
    'escalade',
    'escalader',
    'escalate',
    'escalated',
    'escalating',
    'escalation',
    'escalator',
    'escallop',
    'escapade',
    'escape',
    'escaped',
    'escapee',
    'escapement',
    'escapes',
    'escaping',
    'escapism',
    'escapist',
    'escapologist',
    'escapology',
    'escargot',
    'escarole',
    'escarp',
    'escarpment',
    'eschalot',
    'eschar',
    'eschatological',
    'eschatologist',
    'eschatology',
    'eschaton',
    'escheat',
    'escherichia',
    'eschew',
    'eschrichtiidae',
    'eschrichtius',
    'eschscholtzia',
    'escolar',
    'escort',
    'escorting',
    'escorts',
    'escritoire',
    'escrow',
    'escudo',
    'escudos',
    'escutcheon',
    'ese',
    'esfahan',
    'esidrix',
    'eskalith',
    'esker',
    'eskimo',
    'eskimos',
    'esm',
    'esmolol',
    'esocidae',
    'esop',
    'esophageal',
    'esophagitis',
    'esophagogastric',
    'esophagoscope',
    'esophagus',
    'esoteric',
    'esoterica',
    'esotropia',
    'esox',
    'esp',
    'espadrille',
    'espagnole',
    'espalier',
    'espana',
    'esparcet',
    'especial',
    'especially',
    'esperantido',
    'esperanto',
    'espial',
    'espionage',
    'esplanade',
    'espoo',
    'espousal',
    'espouse',
    'espoused',
    'espouses',
    'espousing',
    'espresso',
    'esprit',
    'espy',
    'esq',
    'esquimau',
    'esquire',
    'esr',
    'essay',
    'essayed',
    'essayer',
    'essayist',
    'essays',
    'esselen',
    'essen',
    'essence',
    'essene',
    'essenes',
    'essential',
    'essentiality',
    'essentially',
    'essentialness',
    'essentials',
    'essex',
    'essonite',
    'est',
    'establish',
    'established',
    'establishes',
    'establishing',
    'establishment',
    'establishmentarianism',
    'establishmentism',
    'establishments',
    'estaminet',
    'estate',
    'estates',
    'estazolam',
    'esteem',
    'esteemed',
    'esteems',
    'ester',
    'esterify',
    'esters',
    'esther',
    'esthesia',
    'esthesis',
    'esthete',
    'esthetic',
    'esthetical',
    'esthetically',
    'esthetician',
    'esthetics',
    'esthonia',
    'esthonian',
    'estimable',
    'estimate',
    'estimated',
    'estimates',
    'estimating',
    'estimation',
    'estimator',
    'estival',
    'estivate',
    'estivation',
    'estonia',
    'estonian',
    'estoppel',
    'estradiol',
    'estragon',
    'estrange',
    'estranged',
    'estrangement',
    'estranging',
    'estrilda',
    'estriol',
    'estrogen',
    'estrogenic',
    'estrone',
    'estronol',
    'estrous',
    'estrus',
    'estuarial',
    'estuaries',
    'estuarine',
    'estuary',
    'esurience',
    'esurient',
    'eta',
    'etagere',
    'etamin',
    'etamine',
    'etanercept',
    'etc',
    'etcetera',
    'etch',
    'etched',
    'etcher',
    'etches',
    'etching',
    'etchings',
    'etd',
    'eternal',
    'eternalise',
    'eternalize',
    'eternally',
    'eternise',
    'eternity',
    'eternize',
    'etf',
    'ethanal',
    'ethanamide',
    'ethane',
    'ethanediol',
    'ethanoate',
    'ethanol',
    'ethchlorvynol',
    'ethel',
    'ethelbert',
    'ethelred',
    'ethene',
    'ether',
    'ethereal',
    'etherealize',
    'etherialise',
    'etherify',
    'etherise',
    'etherize',
    'ethernet',
    'ethernets',
    'ethic',
    'ethical',
    'ethically',
    'ethician',
    'ethicism',
    'ethicist',
    'ethics',
    'ethiopia',
    'ethiopian',
    'ethmoid',
    'ethmoidal',
    'ethnarch',
    'ethnic',
    'ethnical',
    'ethnically',
    'ethnicity',
    'ethnocentric',
    'ethnocentrism',
    'ethnographer',
    'ethnographic',
    'ethnographical',
    'ethnography',
    'ethnologic',
    'ethnological',
    'ethnologist',
    'ethnology',
    'ethnos',
    'ethocaine',
    'ethologist',
    'ethology',
    'ethos',
    'ethosuximide',
    'ethoxyethane',
    'ethrane',
    'ethril',
    'ethyl',
    'ethylene',
    'ethyne',
    'etienne',
    'etiolate',
    'etiolated',
    'etiolates',
    'etiolation',
    'etiologic',
    'etiological',
    'etiologist',
    'etiology',
    'etiquette',
    'etna',
    'etodolac',
    'eton',
    'etonian',
    'etropus',
    'etruria',
    'etruscan',
    'etruscans',
    'etude',
    'etui',
    'etymological',
    'etymologise',
    'etymologist',
    'etymologize',
    'etymologized',
    'etymologizing',
    'etymology',
    'etymon',
    'eu',
    'euarctos',
    'euascomycetes',
    'eubacteria',
    'eubacteriales',
    'eubacterium',
    'eubryales',
    'eucalypt',
    'eucalypts',
    'eucalyptus',
    'eucarya',
    'eucaryote',
    'eucaryotic',
    'eucharist',
    'eucharistic',
    'euchre',
    'eucinostomus',
    'euclid',
    'euclidean',
    'euclidian',
    'eudaemon',
    'eudaemonia',
    'eudaemonic',
    'eudaimonia',
    'eudemon',
    'eudemonic',
    'eudemonism',
    'euderma',
    'eudiometer',
    'eudyptes',
    'eugene',
    'eugenia',
    'eugenic',
    'eugenics',
    'euglena',
    'euglenaceae',
    'euglenid',
    'euglenoid',
    'euglenophyceae',
    'euglenophyta',
    'euglenophyte',
    'eukaryote',
    'eukaryotic',
    'euler',
    'eulogies',
    'eulogise',
    'eulogist',
    'eulogistic',
    'eulogium',
    'eulogize',
    'eulogized',
    'eulogy',
    'eumeces',
    'eumenes',
    'eumenides',
    'eumetopias',
    'eumops',
    'eumycetes',
    'eumycota',
    'eunectes',
    'eunuch',
    'eunuchoidism',
    'euonymus',
    'eupatorium',
    'euphagus',
    'euphausiacea',
    'euphemise',
    'euphemism',
    'euphemisms',
    'euphemistic',
    'euphemistically',
    'euphemize',
    'euphonic',
    'euphonical',
    'euphonious',
    'euphonium',
    'euphonous',
    'euphony',
    'euphorbia',
    'euphorbiaceae',
    'euphorbium',
    'euphoria',
    'euphoriant',
    'euphoric',
    'euphory',
    'euphractus',
    'euphrates',
    'euphrosyne',
    'euphuism',
    'euplectella',
    'eupnea',
    'eupneic',
    'eupnoea',
    'eupnoeic',
    'euproctis',
    'eurafrican',
    'eurasia',
    'eurasian',
    'eurasiatic',
    'eureka',
    'eurhythmics',
    'eurhythmy',
    'euripides',
    'euro',
    'eurobabble',
    'eurocentric',
    'eurocentrism',
    'eurocurrency',
    'eurodollar',
    'euronithopod',
    'euronithopoda',
    'europa',
    'europan',
    'europe',
    'european',
    'europeanisation',
    'europeanise',
    'europeanization',
    'europeanize',
    'europeans',
    'europen',
    'europium',
    'europocentric',
    'europol',
    'eurotiales',
    'eurotium',
    'euryale',
    'euryalida',
    'eurydice',
    'eurylaimi',
    'eurylaimidae',
    'eurypterid',
    'eurypterida',
    'eurythmics',
    'eurythmy',
    'eusebius',
    'eusporangiate',
    'eusporangium',
    'eustachian',
    'eustachio',
    'eustoma',
    'eutamias',
    'eutectic',
    'euterpe',
    'euthanasia',
    'euthenics',
    'eutheria',
    'eutherian',
    'euthynnus',
    'eutrophic',
    'eutrophication',
    'ev',
    'evacuant',
    'evacuate',
    'evacuated',
    'evacuation',
    'evacuee',
    'evade',
    'evaded',
    'evades',
    'evading',
    'evaluate',
    'evaluated',
    'evaluates',
    'evaluating',
    'evaluation',
    'evaluative',
    'evaluator',
    'evanesce',
    'evanescence',
    'evanescent',
    'evangel',
    'evangelical',
    'evangelicalism',
    'evangelise',
    'evangelism',
    'evangelist',
    'evangelistic',
    'evangelize',
    'evangelized',
    'evans',
    'evansville',
    'evaporable',
    'evaporate',
    'evaporated',
    'evaporates',
    'evaporating',
    'evaporation',
    'evaporative',
    'evaporite',
    'evaporometer',
    'evasion',
    'evasive',
    'evasively',
    'evasiveness',
    'eve',
    'even',
    'evenfall',
    'evenhanded',
    'evening',
    'evenings',
    'eveningwear',
    'evenk',
    'evenki',
    'evenly',
    'evenness',
    'evensong',
    'event',
    'eventful',
    'eventide',
    'eventration',
    'events',
    'eventual',
    'eventuality',
    'eventually',
    'eventuate',
    'ever',
    'everest',
    'everglades',
    'evergreen',
    'evergreens',
    'everlasting',
    'everlastingness',
    'evernia',
    'evers',
    'eversion',
    'evert',
    'everting',
    'every',
    'everybody',
    'everyday',
    'everydayness',
    'everyman',
    'everyone',
    'everything',
    'everywhere',
    'evict',
    'evicted',
    'eviction',
    'evidence',
    'evidenced',
    'evidencing',
    'evident',
    'evidential',
    'evidentiary',
    'evil',
    'evildoer',
    'evildoing',
    'evilness',
    'evils',
    'evince',
    'evincing',
    'eviscerate',
    'eviscerated',
    'evisceration',
    'evitable',
    'evocation',
    'evocative',
    'evoke',
    'evoked',
    'evokes',
    'evoking',
    'evolution',
    'evolutionarily',
    'evolutionary',
    'evolutionism',
    'evolutionist',
    'evolve',
    'evolved',
    'ew',
    'ewe',
    'ewenki',
    'ewer',
    'ewing',
    'ex',
    'exabit',
    'exabits',
    'exabyte',
    'exabytes',
    'exacerbate',
    'exacerbating',
    'exacerbation',
    'exact',
    'exacta',
    'exacted',
    'exacting',
    'exaction',
    'exactitude',
    'exactly',
    'exactness',
    'exacum',
    'exaeretodon',
    'exaggerate',
    'exaggerated',
    'exaggeratedly',
    'exaggerating',
    'exaggeration',
    'exalt',
    'exaltation',
    'exalted',
    'exalting',
    'exam',
    'examen',
    'examination',
    'examinations',
    'examine',
    'examined',
    'examinee',
    'examiner',
    'examiners',
    'examines',
    'examining',
    'example',
    'examples',
    'exams',
    'exanimate',
    'exanthem',
    'exanthema',
    'exarch',
    'exarchate',
    'exasperate',
    'exasperated',
    'exasperating',
    'exasperatingly',
    'exasperation',
    'exaugural',
    'exbibit',
    'exbibits',
    'exbibyte',
    'exbibytes',
    'excalibur',
    'excavate',
    'excavated',
    'excavates',
    'excavating',
    'excavation',
    'excavations',
    'excavator',
    'exceed',
    'exceedance',
    'exceeded',
    'exceeding',
    'exceedingly',
    'exceeds',
    'excel',
    'excelled',
    'excellence',
    'excellencies',
    'excellency',
    'excellent',
    'excelling',
    'excelsa',
    'excelsior',
    'except',
    'excepting',
    'exception',
    'exceptionable',
    'exceptional',
    'exceptionally',
    'exceptions',
    'excerpt',
    'excerption',
    'excerpts',
    'excess',
    'excesses',
    'excessive',
    'excessively',
    'excessiveness',
    'exchange',
    'exchangeability',
    'exchangeable',
    'exchanged',
    'exchanger',
    'exchanges',
    'exchanging',
    'exchequer',
    'excise',
    'excised',
    'exciseman',
    'excising',
    'excision',
    'excitability',
    'excitable',
    'excitableness',
    'excitant',
    'excitation',
    'excitative',
    'excitatory',
    'excite',
    'excited',
    'excitement',
    'excitements',
    'excites',
    'exciting',
    'excitingly',
    'exclaim',
    'exclaiming',
    'exclamation',
    'exclamations',
    'exclamatory',
    'exclude',
    'excluded',
    'excludes',
    'excluding',
    'exclusion',
    'exclusive',
    'exclusively',
    'exclusiveness',
    'excogitate',
    'excogitating',
    'excogitation',
    'excogitative',
    'excogitator',
    'excommunicate',
    'excommunicated',
    'excommunication',
    'excoriate',
    'excoriation',
    'excrement',
    'excrescence',
    'excrescences',
    'excrescent',
    'excreta',
    'excrete',
    'excreted',
    'excretes',
    'excreting',
    'excretion',
    'excretory',
    'excruciate',
    'excruciating',
    'excruciation',
    'exculpate',
    'exculpated',
    'exculpation',
    'exculpatory',
    'excursion',
    'excursionist',
    'excursions',
    'excursive',
    'excursus',
    'excusable',
    'excusatory',
    'excuse',
    'excused',
    'excuser',
    'excuses',
    'excusing',
    'exec',
    'execrable',
    'execrate',
    'execrated',
    'execration',
    'executability',
    'executable',
    'executant',
    'execute',
    'executed',
    'executes',
    'executing',
    'execution',
    'executioner',
    'executions',
    'executive',
    'executives',
    'executor',
    'executors',
    'executrix',
    'exegesis',
    'exegete',
    'exegetic',
    'exegetical',
    'exemplar',
    'exemplary',
    'exemplification',
    'exemplified',
    'exemplifies',
    'exemplify',
    'exemplifying',
    'exempt',
    'exempted',
    'exempting',
    'exemption',
    'exemptions',
    'exenterate',
    'exenteration',
    'exercise',
    'exercised',
    'exerciser',
    'exercises',
    'exercising',
    'exercycle',
    'exergonic',
    'exert',
    'exerted',
    'exerting',
    'exertion',
    'exerts',
    'exes',
    'exfiltrate',
    'exfiltrated',
    'exfoliate',
    'exfoliation',
    'exhalation',
    'exhale',
    'exhaled',
    'exhales',
    'exhaling',
    'exhaust',
    'exhausted',
    'exhaustible',
    'exhausting',
    'exhaustion',
    'exhaustive',
    'exhausts',
    'exhibit',
    'exhibited',
    'exhibiting',
    'exhibition',
    'exhibitioner',
    'exhibitionism',
    'exhibitionist',
    'exhibitionistic',
    'exhibitions',
    'exhibitor',
    'exhibits',
    'exhilarate',
    'exhilarated',
    'exhilarating',
    'exhilaration',
    'exhort',
    'exhortation',
    'exhortative',
    'exhortatory',
    'exhorts',
    'exhumation',
    'exhume',
    'exhumed',
    'exigency',
    'exigent',
    'exiguity',
    'exiguous',
    'exile',
    'exiled',
    'exiles',
    'exilic',
    'exisitng',
    'exist',
    'existed',
    'existence',
    'existent',
    'existential',
    'existentialism',
    'existentialist',
    'existing',
    'exists',
    'exit',
    'exiting',
    'exmoor',
    'exobiology',
    'exocarp',
    'exocentric',
    'exocet',
    'exocoetidae',
    'exocrine',
    'exocycloida',
    'exode',
    'exoderm',
    'exodontia',
    'exodontic',
    'exodontics',
    'exodontist',
    'exodus',
    'exoergic',
    'exogamic',
    'exogamous',
    'exogamy',
    'exogen',
    'exogenic',
    'exogenous',
    'exomphalos',
    'exon',
    'exonerate',
    'exonerated',
    'exonerates',
    'exoneration',
    'exonerative',
    'exonuclease',
    'exophthalmos',
    'exopterygota',
    'exorbitance',
    'exorbitant',
    'exorcise',
    'exorciser',
    'exorcism',
    'exorcist',
    'exorcize',
    'exordium',
    'exoskeleton',
    'exoskeletons',
    'exosphere',
    'exostosis',
    'exoteric',
    'exotherm',
    'exothermal',
    'exothermic',
    'exotic',
    'exoticism',
    'exoticness',
    'exotism',
    'exotoxin',
    'exotropia',
    'expand',
    'expandable',
    'expanded',
    'expandible',
    'expanding',
    'expands',
    'expanse',
    'expansible',
    'expansile',
    'expansion',
    'expansionism',
    'expansionist',
    'expansions',
    'expansive',
    'expansiveness',
    'expansivity',
    'expat',
    'expatiate',
    'expatiation',
    'expatriate',
    'expatriates',
    'expatriation',
    'expect',
    'expectable',
    'expectancy',
    'expectant',
    'expectation',
    'expectations',
    'expected',
    'expectedness',
    'expecting',
    'expectorant',
    'expectorate',
    'expectorated',
    'expectorates',
    'expectoration',
    'expectorator',
    'expects',
    'expedience',
    'expediency',
    'expedient',
    'expedite',
    'expedition',
    'expeditionary',
    'expeditions',
    'expeditious',
    'expeditiousness',
    'expel',
    'expelled',
    'expelling',
    'expels',
    'expend',
    'expendable',
    'expended',
    'expender',
    'expending',
    'expenditure',
    'expenditures',
    'expense',
    'expenses',
    'expensive',
    'expensiveness',
    'experience',
    'experienced',
    'experiences',
    'experiencing',
    'experient',
    'experiential',
    'experiment',
    'experimental',
    'experimentalism',
    'experimentally',
    'experimentation',
    'experimented',
    'experimenter',
    'experimenting',
    'experiments',
    'expert',
    'expertise',
    'expertly',
    'expertness',
    'experts',
    'expiable',
    'expiate',
    'expiation',
    'expiative',
    'expiatory',
    'expiration',
    'expiratory',
    'expire',
    'expired',
    'expires',
    'expiry',
    'explain',
    'explainable',
    'explained',
    'explaining',
    'explains',
    'explanandum',
    'explanans',
    'explanation',
    'explanations',
    'explanatory',
    'expletive',
    'expletives',
    'explicable',
    'explicandum',
    'explicate',
    'explicated',
    'explication',
    'explicit',
    'explicitly',
    'explicitness',
    'explode',
    'exploded',
    'explodes',
    'exploding',
    'exploit',
    'exploitation',
    'exploitative',
    'exploitatory',
    'exploited',
    'exploiter',
    'exploiting',
    'exploitive',
    'exploits',
    'exploration',
    'explorative',
    'exploratory',
    'explore',
    'explored',
    'explorer',
    'explorers',
    'explores',
    'exploring',
    'explosion',
    'explosions',
    'explosive',
    'explosively',
    'explosives',
    'expo',
    'exponent',
    'exponential',
    'exponentially',
    'exponentiation',
    'exponents',
    'export',
    'exportable',
    'exportation',
    'exported',
    'exporter',
    'exporting',
    'exports',
    'expose',
    'exposed',
    'exposes',
    'exposing',
    'exposit',
    'exposition',
    'expositive',
    'expositor',
    'expository',
    'expostulate',
    'expostulation',
    'exposure',
    'exposures',
    'expound',
    'expounded',
    'expounder',
    'expounding',
    'expounds',
    'expres',
    'express',
    'expressage',
    'expressed',
    'expresses',
    'expressible',
    'expressing',
    'expression',
    'expressionism',
    'expressionist',
    'expressionistic',
    'expressionists',
    'expressionless',
    'expressions',
    'expressive',
    'expressiveness',
    'expressly',
    'expressway',
    'expropriate',
    'expropriated',
    'expropriation',
    'expulsion',
    'expunction',
    'expunge',
    'expunging',
    'expurgate',
    'expurgated',
    'expurgation',
    'expurgator',
    'exquisite',
    'exquisitely',
    'exquisiteness',
    'exsanguine',
    'exsanguinous',
    'exsert',
    'exserted',
    'exsiccate',
    'extant',
    'extemporaneous',
    'extemporaneously',
    'extemporary',
    'extempore',
    'extemporisation',
    'extemporise',
    'extemporization',
    'extemporize',
    'extemporized',
    'extend',
    'extendable',
    'extended',
    'extendible',
    'extending',
    'extends',
    'extensible',
    'extensile',
    'extension',
    'extensional',
    'extensions',
    'extensive',
    'extensively',
    'extensiveness',
    'extensor',
    'extent',
    'extenuate',
    'extenuating',
    'extenuation',
    'exterior',
    'exteriorisation',
    'exteriorise',
    'exteriorization',
    'exteriorize',
    'exteriors',
    'exterminable',
    'exterminate',
    'exterminated',
    'exterminates',
    'exterminating',
    'extermination',
    'exterminator',
    'extern',
    'external',
    'externalisation',
    'externalise',
    'externality',
    'externalization',
    'externalize',
    'externalizes',
    'externally',
    'externals',
    'exteroception',
    'exteroceptive',
    'exteroceptor',
    'exterritorial',
    'extinct',
    'extinction',
    'extinguish',
    'extinguishable',
    'extinguished',
    'extinguisher',
    'extinguishers',
    'extinguishes',
    'extinguishing',
    'extirpable',
    'extirpate',
    'extirpation',
    'extol',
    'extoller',
    'extolment',
    'extort',
    'extorted',
    'extorting',
    'extortion',
    'extortionate',
    'extortioner',
    'extortionist',
    'extorts',
    'extra',
    'extracapsular',
    'extracellular',
    'extract',
    'extractable',
    'extracted',
    'extractible',
    'extracting',
    'extraction',
    'extractor',
    'extracts',
    'extracurricular',
    'extradite',
    'extradited',
    'extradition',
    'extrados',
    'extradural',
    'extragalactic',
    'extrajudicial',
    'extralegal',
    'extralinguistic',
    'extramarital',
    'extramural',
    'extraneous',
    'extraneousness',
    'extraordinarily',
    'extraordinariness',
    'extraordinary',
    'extrapolate',
    'extrapolating',
    'extrapolation',
    'extras',
    'extrasensory',
    'extrasystole',
    'extrasystolic',
    'extraterrestrial',
    'extraterritorial',
    'extravagance',
    'extravagancy',
    'extravagant',
    'extravagantly',
    'extravaganza',
    'extravasate',
    'extravasated',
    'extravasation',
    'extraversion',
    'extraversive',
    'extravert',
    'extraverted',
    'extravertive',
    'extreme',
    'extremely',
    'extremeness',
    'extremes',
    'extremism',
    'extremist',
    'extremists',
    'extremities',
    'extremity',
    'extremum',
    'extricable',
    'extricate',
    'extricated',
    'extricates',
    'extrication',
    'extrinsic',
    'extropic',
    'extropy',
    'extrospective',
    'extroversion',
    'extroversive',
    'extrovert',
    'extroverted',
    'extrovertish',
    'extrovertive',
    'extrude',
    'extruded',
    'extruding',
    'extrusion',
    'extrusive',
    'exuberance',
    'exuberant',
    'exuberantly',
    'exuberate',
    'exudate',
    'exudates',
    'exudation',
    'exudations',
    'exude',
    'exuded',
    'exudes',
    'exuding',
    'exult',
    'exultant',
    'exultantly',
    'exultation',
    'exulting',
    'exurbia',
    'exuviae',
    'exuvial',
    'exuviate',
    'eyas',
    'eyck',
    'eye',
    'eyeball',
    'eyeballs',
    'eyebath',
    'eyebrow',
    'eyebrows',
    'eyecup',
    'eyed',
    'eyedness',
    'eyedrop',
    'eyedrops',
    'eyeful',
    'eyeglass',
    'eyeglasses',
    'eyehole',
    'eyeish',
    'eyelash',
    'eyeless',
    'eyelessness',
    'eyelet',
    'eyelets',
    'eyelid',
    'eyelids',
    'eyelike',
    'eyeliner',
    'eyepatch',
    'eyepiece',
    'eyes',
    'eyeshade',
    'eyeshadow',
    'eyeshot',
    'eyesight',
    'eyesore',
    'eyespot',
    'eyespots',
    'eyestrain',
    'eyetooth',
    'eyewash',
    'eyewitness',
    'eyra',
    'eyre',
    'eyrie',
    'eyrir',
    'eyry',
    'eysenck',
    'ezechiel',
    'ezed',
    'ezekias',
    'ezekiel',
    'ezo',
    'ezra']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Text Tokenization API """


from typing import List
from lingpatlab.baseblock import BaseObject, Stopwatch, Enforcer
from functools import lru_cache


class Tokenizer(BaseObject):
    """ Text Tokenization API """

    def __init__(self):
        """ Change Log

        Updated:
            27-Mar-2024
            craigtrim@gmail.com
            *   migrated out of modai in pursuit of
                https://github.com/craigtrim/datapipe-apis/issues/72
        """
        BaseObject.__init__(self, __name__)
        self._custom = None

    @lru_cache
    def input_text(self,
                   input_text: str) -> List[str]:
        """Tokenize with Custom Tokenizer

        Args:
            input_text (str): input text of any length

        Returns:
            list: list of tokens
        """

        sw = Stopwatch()

        if self.isEnabledForDebug:
            Enforcer.is_str(input_text)

        if not self._custom:
            from lingpatlab.tokenizer.svc import TokenizeUseGraffl
            self._custom = TokenizeUseGraffl().process

        tokens: List[str] = self._custom(input_text)

        if self.isEnabledForDebug:
            Enforcer.is_list_of_str(tokens)
            self.logger.debug(
                f"Tokenized input text into {len(tokens)} tokens in {str(sw)}")

        return tokens
